@@ -59,6 +59,7 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
 			     _("Start package manager"), 
 			     RES_START_PM,
 			     NULL);
+      gtk_dialog_set_default_response (GTK_DIALOG(dialog), RES_START_PM);
       break;
    case CD_WITH_DISTUPGRADER:
       title = _("Upgrade volume detected");
@@ -74,7 +75,7 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
 			     _("Run upgrade"), 
 			     RES_DIST_UPGRADER,
 			     NULL);
-
+      gtk_dialog_set_default_response (GTK_DIALOG(dialog), RES_DIST_UPGRADER);
       break;
    case CD_WITH_ADDONS:
       title = _("Addon volume detected");
@@ -90,7 +91,7 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
 			     _("Start addon installer"), 
 			     RES_ADDON_CD,
 			     NULL);
-
+      gtk_dialog_set_default_response (GTK_DIALOG(dialog), RES_ADDON_CD);
       break;
       
    case CD_WITH_APTONCD:
@@ -106,13 +107,14 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
 			     _("Start package manager"), 
 			     RES_START_PM,
 			     NULL);
+      gtk_dialog_set_default_response (GTK_DIALOG(dialog), RES_START_PM);
       break;      
    default:
       g_assert_not_reached();
    }
 
    gtk_window_set_title(GTK_WINDOW(dialog), title);
-   gtk_window_set_keep_above(GTK_WINDOW(dialog), TRUE);
+   gtk_window_set_skip_taskbar_hint (GTK_WINDOW(dialog), FALSE);
    gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), markup);
 
    int res = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -316,7 +318,7 @@ hal_property_modified(LibHalContext *ctx, const char *udi, const char *key,
       return;
    }
    if (g_ascii_strcasecmp(media_type, "cdrom") != 0) {
-      g_warning("no cdrom: %s\n",media_type);
+      //g_warning("no cdrom: %s\n",media_type);
       return;
    }
       
