@@ -60,10 +60,18 @@ gboolean update_timer_finished(gpointer data);
 // causes the applet to "ungray"
 #define TIMEOUT_APT_RUN 120 /* 120 sec */
 
+// force statup even if the user is not in the admin group
+static gboolean FORCE_START=FALSE;
+
+// force gksu for all menu actions
+static gboolean FORCE_GKSU=FALSE;
+
+// delay on startup
+static int STARTUP_DELAY=60000;
 
 void invoke(gchar *cmd, gchar *desktop, gboolean with_gksu)
 {
-   if(with_gksu)
+   if(with_gksu || FORCE_GKSU)
       invoke_with_gksu(cmd, desktop, FALSE);
    else
       g_spawn_command_line_async(cmd, NULL);
@@ -109,6 +117,7 @@ trayapplet_create (TrayApplet *un, char *name)
   - /var/lib/apt/lists/lock
   - /var/lib/apt/lists/ *
   - /var/lib/dpkg/lock
+  - /var/lib/apt/periodic/update-success-stamp
 */
 void
 monitor_cb(GnomeVFSMonitorHandle *handle,
@@ -136,7 +145,8 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
       || strcmp(info_uri,"file:///var/lib/dpkg/status") == 0) {
       un->apt_get_runing=TRUE;
    } 
-   if(strstr(info_uri, "/var/lib/update-notifier/dpkg-run-stamp")) {
+   if(strstr(info_uri, "/var/lib/update-notifier/dpkg-run-stamp") ||
+      strstr(info_uri, "/var/lib/apt/periodic/update-success-stamp")) {
       un->dpkg_was_run = TRUE;
    } 
    if(strstr(info_uri, REBOOT_FILE)) {
@@ -275,8 +285,8 @@ gboolean monitor_init(UpgradeNotifier *un)
 
    // monitor thise dirs
    static const char *monitor_dirs[] = { 
-      "/var/lib/apt/lists/", "/var/lib/apt/list/partial", 
-      "/var/cache/apt/archives/", "/var/cache/apt/archives/partial", 
+      "/var/lib/apt/lists/", "/var/lib/apt/lists/partial/", 
+      "/var/cache/apt/archives/", "/var/cache/apt/archives/partial/", 
       HOOKS_DIR, 
       CRASHREPORT_DIR,
       NULL};
@@ -291,6 +301,7 @@ gboolean monitor_init(UpgradeNotifier *un)
    static const char *monitor_files[] = { 
       "/var/lib/dpkg/status", 
       "/var/lib/update-notifier/dpkg-run-stamp", 
+      "/var/lib/apt/periodic/update-success-stamp",
       REBOOT_FILE,
       UNICAST_LOCAL_AVAHI_FILE,
       NULL};
@@ -318,7 +329,7 @@ tray_icons_init(UpgradeNotifier *un)
    /* new upates tray icon */
    un->update = g_new0 (TrayApplet, 1);
 
-   trayapplet_create(un->update, "updates-notifier");
+   trayapplet_create(un->update, "software-update-available");
    update_tray_icon_init(un->update);
 
    /* update hook icon*/
@@ -347,22 +358,24 @@ in_admin_group()
 {
    int i, ng = 0;
    gid_t *groups = NULL;
-   struct passwd *pw = getpwuid(getuid());
-   if (pw == NULL)
-      return TRUE;
 
    struct group *grp = getgrnam("admin");
    if(grp == NULL) 
       return TRUE;
-   
-   if (getgrouplist(pw->pw_name, pw->pw_gid, NULL, &ng) < 0) {
-      groups = (gid_t *) malloc(ng * sizeof (gid_t));
-      getgrouplist(pw->pw_name, pw->pw_gid, groups, &ng);
+
+   ng = getgroups (0, NULL);
+   groups = (gid_t *) malloc (ng * sizeof (gid_t));
+
+   i = getgroups (ng, groups);
+   if (i != ng) {
+     free (groups);
+     return TRUE;
    }
+   
    for(i=0;i<ng;i++) {
       if(groups[i] == grp->gr_gid) {
-	 free(groups);
-	 return TRUE;
+        free(groups);
+        return TRUE;
       }
    }
    
@@ -375,6 +388,9 @@ in_admin_group()
 static GOptionEntry entries[] = 
 {
    { "debug-hooks", 0, 0, G_OPTION_ARG_NONE, &HOOK_DEBUG, "Enable hooks debugging"},
+   { "force", 0, 0, G_OPTION_ARG_NONE, &FORCE_START, "Force start even if the user is not in the admin group"},
+   { "force-use-gksu", 0, 0, G_OPTION_ARG_NONE, &FORCE_GKSU, "Force running all commands (update-manager, synaptic) with gksu" },
+   { "startup-delay", 0, 0, G_OPTION_ARG_INT, &STARTUP_DELAY, "Delay statup by given amount of miliseconds" },
    { NULL }
 };
 
@@ -405,7 +421,7 @@ main (int argc, char *argv[])
 	
 	// check if we should run at all (see HideAdminTools spec
 	// on https://wiki.ubuntu.com/HideAdminToolsToUsers)
-	if(!in_admin_group()) {
+	if(!in_admin_group() && !FORCE_START) {
 	   g_warning("not starting because user is not in admin group\n");
 	   exit(0);
 	}
@@ -433,9 +449,9 @@ main (int argc, char *argv[])
 	   g_mkdir(dirname, 0700);
 	g_free(dirname);
 
-	// create the icons with a timeout
-	//g_timeout_add(5000, (GSourceFunc)(tray_icons_init), un);
-	tray_icons_init(un);
+	// delay icon creation for 30s so that the desktop 
+	// login is not slowed down by update-notifier
+	g_timeout_add(STARTUP_DELAY, (GSourceFunc)(tray_icons_init), un);
 
         // initial check for avahi
         avahi_disabled_check();
